@@ -1,6 +1,7 @@
 # net_genconfig.__main__
 
 
+
 import net_genconfig
 
 import argparse
@@ -645,9 +646,7 @@ if debug:
 
 # read in the inventory
 
-inventory_obj = NetInventory(inventory_dirname, debug=debug)
-
-inventory = inventory_obj.get()
+inventory = NetInventory(inventory_dirname, debug=debug)
 
 
 if dump_inventory:
